#
# spec file for package skanlite
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without released
Name:           skanlite
Version:        24.12.2
Release:        1.1
Summary:        Image Scanner Application
License:        LGPL-2.1-or-later
URL:            https://www.kde.org/applications/graphics/skanlite/
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(KSaneWidgets6)
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
Obsoletes:      %{name}-doc < %{version}

%description
Skanlite is an image scanner application by KDE.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6 -DBUILD_WITH_QT6:BOOL=TRUE

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-html --all-name

%files
%license LICENSES/*
%doc %lang(en) %{_kf6_htmldir}/en/skanlite/
%{_kf6_applicationsdir}/org.kde.skanlite.desktop
%{_kf6_appstreamdir}/org.kde.skanlite.appdata.xml
%{_kf6_bindir}/skanlite
%{_kf6_iconsdir}/hicolor/scalable/apps/org.kde.skanlite.svg

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/skanlite/

%changelog
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- No code change since 24.12.1
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- No code change since 24.11.80
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 24.08.3:
  * USe clang format
  * Ignore auto-generated .clang-format
  * Use clang format
  * Use nullptr
  * Remove qt5 code
  * Initialize to nullptr
  * Use std::as_const directly
  * Add parent directly
  * Fix mem leak
  * Use ECMDeprecationSettings
  * It's qt6 now
  * Require Qt6
  * Initialize KCrash
  * Choose icon name that more suitable for its behavior
  * flatpak: Update to Sdk version 6.7
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- Changes since 24.08.2:
  * Make flatpak CI Qt6
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 24.05.2:
  * Fix filename of icon so that it is installed to proper location
  * Enforce passing tests
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Changes since 24.02.2:
  * appstream: replace deprecated developer_name /w developer, update type
  * Remove unused Qt5Compat dependency
  * Appdata: Add launchable parameter and screenshot caption
  * org.kde.skanlite.appdata: Add developer_name
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- No code change since 24.02.0
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- No code change since 24.01.95
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Fri Dec 15 2023 Christophe Marin <christophe@krop.fr>
- Require extra-cmake-modules at build time
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * snapcraft: add license header.
  * snapcraft: initial import snapcraft files.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- No code change since 23.04.3
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Don't use deprecated variable
  * Add content rating to appdata
  * Use forward declaration
  * Fixed delete imageSaver
  * Change button layout to match spectacle (kde#448327)
  * Don't use help role for about button
  * Change build system for building against qt6
  * Don't use deprecated variable
  * Remove unused include
  * It's enabled by default in qt6
  * Mark kdoctool as optional
  * Make build autotest even if we use BUILD_TESTING
  * do not search for new devices unconditionally
  * Add CI
  * use state config for scanner settings
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * do not search for new devices unconditionally
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- No code change since 21.11.80
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Changes since 21.08.3:
  * Use more target centric cmake code
  * Minor: s/Q_DECL_OVERRIDE/override/
  * add single image PDF support
  * Add .kde-ci.yml
  * Only depend on major.minor version of KF5Sane
  * remember last used scanner device and open it when launching skanlite (kde#435030)
  * Remove mention of libksane and SANE from description
  * give focus to KSaneWidget (kde#430238)
  * fix preselecting the image format with the one from the settings dialog.
    image/+fileSuffix does not always correspond to the mimetype (kde#441223)
  * describe that skanlite is for photo scanning with flatbed scanners
  * Install app icon (kde#441740)
  * additional cleanup
  * fix image saving when preview is not shown (kde#440970)
  * convert license statements to SPDX
  * various cleanups
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Changes since 21.08.1:
  * Only depend on major.minor version of KF5Sane
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * fix image saving when preview is not shown (kde#440970)
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
- Drop obsolete patch:
  * Fix-compilation-with-Qt-before-5.14.patch
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- No code change since 21.07.80
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Skanlite is now released with KDE Gear.
* Sat Apr 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update URL.
- Use %%kf5_find_htmldocs
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
* Wed Jul 15 2020 wbauer@tmo.at
- Update to version 2.2.0:
  * Saving is moved to a thread to not freeze the interface while
    saving
  * D-Bus interface for hotkeys and controlling scanning
  * Bug fixes
- Add Fix-compilation-with-Qt-before-5.14.patch to fix build on
  Leap 15.2
- Switch Qt5/KF5 BuildRequires to cmake() notation
- Run spec-cleaner
* Tue Apr  3 2018 wbauer@tmo.at
- Update to version 2.1.0.1:
  * Add translations that were missing in 2.1.0 (kde#392598)
- Update to version 2.1.0:
  * Allow index to start from 0 (kde#360432)
  * D-BUS support
  * Bugfix: wrong folder selection dialog behavior (kde#377929)
  * Fix DPI info in 16-bit PNG
  * Fix handling of empty prefix
  * Correct display of applied filename templates
  * Default to PNG format if no format is provided (kde#374315)
* Mon Oct 31 2016 wbauer@tmo.at
- Fix source URL
* Mon Oct 31 2016 wbauer@tmo.at
- Update to version 2.0.1:
  * added appdata-xml
  * updated documentation
- Removed upstreamed patch fix_translations_install.patch
* Thu Aug  4 2016 asterios.dramis@gmail.com
- Update to version 2.0:
  * Port to Kf5.
- Added lang subpackage.
- Merged doc subpackage with the main package in order to have the
  english help files in the main package. Obsolete the doc
  subpackage.
- Added build requirements pkgconfig(Qt5Gui) and
  pkgconfig(Qt5Widgets).
- Added a patch "fix_translations_install.patch" to fix the
  installation of translation (mo) files.
* Mon Jan 18 2016 tittiatcoke@gmail.com
- Update to the latest git snapshot from upstream. This contains
  the rework done to make it work with KDE Frameworks. Unfortunately
  this means that the lang package is gone for the moment, but at
  least the program is still there as that the required libraries
  are only available in a KF5 based version
* Wed Jan  1 2014 hrvoje.senjan@gmail.com
- Update to version 1.1:
  * kio support
* Thu Feb 28 2013 asterios.dramis@gmail.com
- Update to version 1.0:
  * Fix "save crash" when libksane returns an odd number sized buffer in 16 bit
    mode
    kde#314108
  * Save sequence number across sessions
    kde#202432
  * Add option to set sequence-number. Do not open "first image" dialog after
    settings dialog has been canceled
    kde#310687
    kde#310688
    kde#310689
* Wed Sep 26 2012 asterios.dramis@gmail.com
- Update to version 0.9:
  * (Fix regression) Base suggested file name on previous name.
  * Remove the save without asking and keep the ask for first, because you
    probably want to see where the files go anyways the first time around.
- Keep only the english documentation in the doc subpackage (move the other
  languages to the lang subpackage).
* Mon Dec 19 2011 asterios.dramis@gmail.com
- Update to version 0.8:
  * Save scanner options on exit and restore them on next start.
  * Add option to disable automatic selection of scan area(s).
- Spec file updates:
  * Use libkde4-devel instead of libkdepimlibs4-devel (not needed) in
    BuildRequires:.
  * Recommend instead of Suggest the doc and lang subpackages.
  * Removed /sbin/ldconfig %%post/%%postun sections (not needed).
* Sat Oct  8 2011 toddrme2178@gmail.com
- Moved all documentation to the documentation package
  (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Tue Sep 13 2011 toddrme2178@gmail.com
- Split translations (fix for RPMLINT warning)
- Split documentation (fix for RPMLINT warning)
- Added Url tag (fix for RPMLINT warning)
- Removed KDE SC 3 provides (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Thu Dec  2 2010 tittiatcoke@gmail.com
- Update to 0.7
  * fix save file name regression
* Fri Nov 26 2010 tittiatcoke@gmail.com
- update to 0.6
  - Fix compilation problem.
  - Fix save window size bug.
* Thu Nov 18 2010 tittiatcoke@gmail.com
- update to 0.5
  - Add 16 bits/color support for PNG images.
  - Save window size on exit.
  - Fix the "Remember last saved image path/type" regressio
* Fri Jun 25 2010 beineri@opensuse.org
- fix build for <11.2
* Mon Mar  8 2010 llunak@novell.com
- fix build
* Wed Feb 24 2010 llunak@novell.com
- update to 0.4-kde4.4.0: fix build with gcc-4.5
* Sun Jan 31 2010 beineri@opensuse.org
- revert last, fix build different and keep KDE:Backports working
* Fri Jan 29 2010 coolo@novell.com
- add oxygen-icon-theme-large to fix build
* Mon Aug 31 2009 beineri@opensuse.org
- update to 0.3-kde4.3.1: updated translations
* Fri Jul 31 2009 beineri@opensuse.org
- update to 0.3-kde4.3.0: updated translations
* Wed Jun  3 2009 beineri@opensuse.org
- update to 0.3-kde4.2.4: updated translations
* Sat May  9 2009 beineri@opensuse.org
- don't use icon from desktop-data-openSUSE but oxygen-icon-theme
* Wed May  6 2009 beineri@opensuse.org
- update to 0.3-kde4.2.3: updated translations
* Sun Apr 26 2009 beineri@opensuse.org
- document and limit doc directory work-arounds
* Tue Mar 31 2009 beineri@opensuse.org
- update to 0.3-kde4.2.2:
  * Add a scan mode "Open the save dialog for the first image only"
  * Sync the settings on settings dialog exit to ensure that the
    changes are saved.
* Fri Jan 23 2009 stbinner@suse.de
- update to 0.2-kde4.2.0
* Wed Jan 21 2009 stbinner@suse.de
- adapt build requirements
* Sun Jan 11 2009 stbinner@suse.de
- update to 0.2-kde4.1.96
* Thu Nov 20 2008 stbinner@suse.de
- add SLE provides/obseletes
* Sun Oct 19 2008 stbinner@suse.de
- define icon in .desktop file
* Sat Sep 20 2008 stbinner@suse.de
- initial package
